@@ -20,16 +20,16 @@
 
 /**
  * SECTION:element-deinterlace
+ * @title: deinterlace
  *
  * Deinterlacing using based on fragment shaders.
  *
- * <refsect2>
- * <title>Examples</title>
+ * ## Examples
  * |[
  * gst-launch-1.0 videotestsrc ! glupload ! gldeinterlace ! glimagesink
  * ]|
  * FBO (Frame Buffer Object) and GLSL (OpenGL Shading Language) are required.
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -294,10 +294,8 @@ gst_gl_deinterlace_ghash_func_clean (gpointer key, gpointer value,
     gpointer data)
 {
   GstGLShader *shader = (GstGLShader *) value;
-  GstGLFilter *filter = (GstGLFilter *) data;
 
-  //blocking call, wait the opengl thread has destroyed the shader
-  gst_gl_context_del_shader (GST_GL_BASE_FILTER (filter)->context, shader);
+  gst_object_unref (shader);
 
   value = NULL;
 }
